@@ -1,4 +1,3 @@
-from collections import Counter
 from collections.abc import Iterable
 from functools import partial
 from pathlib import Path
@@ -6,12 +5,14 @@ from pathlib import Path
 from cognite.client.data_classes._base import T_CogniteResourceList
 from rich.console import Console
 
+from cognite_toolkit._cdf_tk.constants import DATA_MANIFEST_STEM, DATA_RESOURCE_DIR
 from cognite_toolkit._cdf_tk.exceptions import ToolkitValueError
-from cognite_toolkit._cdf_tk.storageio import StorageIO, TableStorageIO
-from cognite_toolkit._cdf_tk.utils.file import safe_write, to_directory_compatible, yaml_safe_dump
+from cognite_toolkit._cdf_tk.storageio import ConfigurableStorageIO, StorageIO, T_Selector, TableStorageIO
+from cognite_toolkit._cdf_tk.tk_warnings import LowSeverityWarning
+from cognite_toolkit._cdf_tk.utils.file import safe_write, sanitize_filename, yaml_safe_dump
 from cognite_toolkit._cdf_tk.utils.fileio import TABLE_WRITE_CLS_BY_FORMAT, Compression, FileWriter, SchemaColumn
 from cognite_toolkit._cdf_tk.utils.producer_worker import ProducerWorkerExecutor
-from cognite_toolkit._cdf_tk.utils.useful_types import T_ID, JsonVal, T_Selector, T_WritableCogniteResourceList
+from cognite_toolkit._cdf_tk.utils.useful_types import T_ID, JsonVal, T_WritableCogniteResourceList
 
 from ._base import ToolkitCommand
 
@@ -38,22 +39,24 @@ class DownloadCommand(ToolkitCommand):
             compression: The compression method to use for the downloaded files (e.g., "none", "gzip").
             limit: The maximum number of items to download for each selected set. If None, all items will be downloaded.
         """
-        target_directory = output_dir / io.FOLDER_NAME
-        target_directory.mkdir(parents=True, exist_ok=True)
         compression_cls = Compression.from_name(compression)
 
         console = Console()
-        filestem_counter: dict[str, int] = Counter()
         for selector in selectors:
+            target_dir = output_dir / selector.group
             if verbose:
-                console.print(f"Downloading {io.DISPLAY_NAME} '{selector!s}' to {target_directory.as_posix()!r}")
+                console.print(f"Downloading {io.DISPLAY_NAME} '{selector!s}' to {target_dir.as_posix()!r}")
 
-            filestem = to_directory_compatible(str(selector))
-            if filestem_counter[filestem] > 0:
-                filestem = f"{filestem}_{filestem_counter[filestem]}"
-            filestem_counter[filestem] += 1
             iteration_count = self._get_iteration_count(io, selector, limit)
+            filestem = sanitize_filename(str(selector))
+            if self._already_downloaded(target_dir, filestem):
+                warning = LowSeverityWarning(
+                    f"Data for {selector!s} already exists in {target_dir.as_posix()!r}. Skipping download."
+                )
+                self.warn(warning, console=console)
+                continue
 
+            selector.dump_to_file(target_dir)
             columns: list[SchemaColumn] | None = None
             if file_format in TABLE_WRITE_CLS_BY_FORMAT and isinstance(io, TableStorageIO):
                 columns = io.get_schema(selector)
@@ -63,7 +66,7 @@ class DownloadCommand(ToolkitCommand):
                 )
 
             with FileWriter.create_from_format(
-                file_format, target_directory, io.KIND, compression_cls, columns=columns
+                file_format, target_dir, io.KIND, compression_cls, columns=columns
             ) as writer:
                 executor = ProducerWorkerExecutor[T_WritableCogniteResourceList, list[dict[str, JsonVal]]](
                     download_iterable=io.stream_data(selector, limit),
@@ -74,19 +77,21 @@ class DownloadCommand(ToolkitCommand):
                     max_queue_size=8 * 10,  # 8 workers, 10 items per worker
                     download_description=f"Downloading {selector!s}",
                     process_description="Processing",
-                    write_description=f"Writing to {target_directory.as_posix()!r} in files with stem {filestem!r}",
+                    write_description=f"Writing to {target_dir.as_posix()!r} in files with stem {filestem!r}",
                     console=console,
                 )
                 executor.run()
                 executor.raise_on_error()
                 file_count = writer.file_count
 
-            for config in io.configurations(selector):
-                config_file = output_dir / config.folder_name / f"{filestem}.{config.kind}.yaml"
-                config_file.parent.mkdir(parents=True, exist_ok=True)
-                safe_write(config_file, yaml_safe_dump(config.value))
+            if isinstance(io, ConfigurableStorageIO):
+                for config in io.configurations(selector):
+                    filename = config.filename or filestem
+                    config_file = target_dir / DATA_RESOURCE_DIR / config.folder_name / f"{filename}.{config.kind}.yaml"
+                    config_file.parent.mkdir(parents=True, exist_ok=True)
+                    safe_write(config_file, yaml_safe_dump(config.value))
 
-            console.print(f"Downloaded {selector!s} to {file_count} file(s) in {target_directory.as_posix()!r}.")
+            console.print(f"Downloaded {selector!s} to {file_count} file(s) in {target_dir.as_posix()!r}.")
 
     @staticmethod
     def _get_iteration_count(
@@ -101,3 +106,20 @@ class DownloadCommand(ToolkitCommand):
         if total is not None:
             iteration_count = total // io.CHUNK_SIZE + (1 if total % io.CHUNK_SIZE > 0 else 0)
         return iteration_count
+
+    @staticmethod
+    def _already_downloaded(output_dir: Path, filestem: str) -> bool:
+        if not output_dir.exists():
+            return False
+
+        # Check for multi-part files (e.g. ndjson, csv, parquet)
+        if any(output_dir.glob(f"{filestem}-part-*")):
+            return True
+
+        # Check for single files (e.g. yaml) and exclude the metadata file.
+        manifest_file_name = f"{filestem}.{DATA_MANIFEST_STEM}.yaml"
+        for f in output_dir.glob(f"{filestem}.*"):
+            if f.name != manifest_file_name:
+                return True
+
+        return False
