@@ -1,13 +1,13 @@
-from .assets import MigrateAssetsCommand
 from .canvas import MigrationCanvasCommand
+from .command import MigrationCommand
 from .files import MigrateFilesCommand
 from .prepare import MigrationPrepareCommand
 from .timeseries import MigrateTimeseriesCommand
 
 __all__ = [
-    "MigrateAssetsCommand",
     "MigrateFilesCommand",
     "MigrateTimeseriesCommand",
     "MigrationCanvasCommand",
+    "MigrationCommand",
     "MigrationPrepareCommand",
 ]
