@@ -179,7 +179,10 @@ class UploadFileError(ToolkitError):
     pass
 
 
-class ResourceRetrievalError(ToolkitError): ...
+class ResourceRetrievalError(ToolkitError):
+    def __init__(self, message: str, resources: list[str] | None = None) -> None:
+        super().__init__(message)
+        self.resources = resources
 
 
 class ResourceCreationError(ToolkitError):
