@@ -14,6 +14,7 @@ from contextlib import contextmanager
 from dataclasses import dataclass, field
 from pathlib import Path
 from typing import Any, Literal, TypeVar, overload
+from zipfile import ZipFile
 
 import pandas as pd
 import yaml
@@ -22,8 +23,6 @@ from rich import print
 from cognite_toolkit._cdf_tk.cdf_toml import CDFToml
 from cognite_toolkit._cdf_tk.constants import ENV_VAR_PATTERN, HINT_LEAD_TEXT, URL
 from cognite_toolkit._cdf_tk.exceptions import (
-    ToolkitFileNotFoundError,
-    ToolkitNotADirectoryError,
     ToolkitValueError,
     ToolkitYAMLFormatError,
 )
@@ -173,8 +172,8 @@ def read_yaml_content(content: str) -> dict[str, Any] | list[dict[str, Any]]:
 _ILLEGAL_CHARACTERS = re.compile(r"[<>:\"/\\|?*\s]")
 
 
-def to_directory_compatible(text: str) -> str:
-    """Convert a string to be compatible with directory names on all platforms"""
+def sanitize_filename(text: str) -> str:
+    """Convert a string to be a valid filename by replacing illegal characters with underscores."""
     cleaned = _ILLEGAL_CHARACTERS.sub("_", text)
     # Replace multiple underscores with a single one
     return re.sub(r"_+", "_", cleaned)
@@ -429,38 +428,31 @@ def get_table_columns(table: Path) -> list[str]:
         raise ToolkitValueError(f"The file {table.name} is not a supported table format (csv, parquet)")
 
 
-def find_adjacent_files(filepath: Path, suffix: str) -> list[Path]:
-    """Find files in the same directory as the given file that have the same
-    prefix and a specific suffix.
+@contextmanager
+def create_temporary_zip(directory: Path, zipname: str) -> typing.Generator[Path, None, None]:
+    """
+    Create a temporary zip file from a directory.
 
     Args:
-        filepath (Path): The path to the file for which to find adjacent files.
-        suffix (str): The suffix to match for the adjacent files.
+        directory: The directory to zip.
+        zipname: The name of the zip file.
 
     Returns:
-        list[Path]: A list of Paths to the adjacent files that match the criteria.
+        A context manager that yields the path to the zip file.
+
     """
-    if not filepath.is_file():
-        raise ToolkitFileNotFoundError(f"The provided path {filepath} is not a file.")
-    return find_files_with_suffix_and_prefix(filepath.parent, filepath.name, suffix=suffix)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        zip_path = Path(tmpdir, zipname)
+        with ZipFile(zip_path, "w", strict_timestamps=False) as zf:
+            for root, _, files in os.walk(directory):
+                root_path = Path(root)
+                arc_root = root_path.relative_to(directory)
 
+                # Add directory entry to preserve directory structure, including empty ones.
+                zf.write(root_path, arcname=str(arc_root))
 
-def find_files_with_suffix_and_prefix(dirpath: Path, name: str, suffix: str) -> list[Path]:
-    """Find files in a directory that have the same prefix as the given name
-
-    Args:
-        dirpath: The directory in which to search for files.
-        name: The name of the file to match against, which should include the prefix.
-        suffix: The suffix to match for the files.
-
-    Returns:
-        list[Path]: A list of Paths to the files that match the criteria.
-    """
-    if not dirpath.is_dir():
-        raise ToolkitNotADirectoryError(f"The provided path {dirpath} is not a directory.")
-    found_files: list[Path] = []
-    for file in dirpath.glob(f"*{suffix}"):
-        filestem = file.name.removesuffix(suffix)
-        if file.is_file() and name.startswith(filestem):
-            found_files.append(file)
-    return found_files
+                for filename in files:
+                    file_path = root_path / filename
+                    arcname = file_path.relative_to(directory)
+                    zf.write(file_path, arcname)
+        yield zip_path
