@@ -1,11 +1,10 @@
 from abc import ABC
 from dataclasses import dataclass
 from datetime import date, datetime
-from typing import IO, ClassVar, Literal, TypeAlias, TypeVar
+from typing import IO, ClassVar, TypeAlias, TypeVar
 
-from cognite_toolkit._cdf_tk.utils.useful_types import JsonVal
+from cognite_toolkit._cdf_tk.utils.useful_types import DataType, JsonVal
 
-DataType: TypeAlias = Literal["string", "integer", "float", "boolean", "json", "date", "timestamp"]
 PrimaryCellValue: TypeAlias = datetime | date | JsonVal
 CellValue: TypeAlias = PrimaryCellValue | list[PrimaryCellValue]
 Chunk: TypeAlias = dict[str, CellValue]
