@@ -1,5 +1,3 @@
-import pytest
-
 from cognite_toolkit._cdf_tk.client import ToolkitClient
 from cognite_toolkit._cdf_tk.commands import MigrationPrepareCommand
 from cognite_toolkit._cdf_tk.commands._migrate.data_model import CONTAINERS, VIEWS
@@ -7,9 +5,6 @@ from cognite_toolkit._cdf_tk.commands._migrate.default_mappings import create_de
 from cognite_toolkit._cdf_tk.data_classes import ResourceDeployResult
 
 
-@pytest.mark.skip(
-    "We will change the migration model and then we cannot have an integration tests deploying it while we are changing it."
-)
 class TestMigrateTimeSeriesCommand:
     def test_migration_prepare_command(
         self,
@@ -21,7 +16,7 @@ class TestMigrateTimeSeriesCommand:
             "containers": len(CONTAINERS),
             "views": len(VIEWS),
             "data models": 1,
-            "view sources": len(create_default_mappings()),
+            "resource view mapping": len(create_default_mappings()),
         }
 
         dry_run_result = cmd.deploy_cognite_migration(toolkit_client, True, verbose=False)
