@@ -4,7 +4,7 @@ import responses
 
 from cognite_toolkit._cdf_tk.client import ToolkitClient, ToolkitClientConfig
 from cognite_toolkit._cdf_tk.commands._migrate.adapter import AssetCentricMigrationIOAdapter, MigrationCSVFileSelector
-from cognite_toolkit._cdf_tk.storageio import AssetIO, InstanceIO
+from cognite_toolkit._cdf_tk.storageio import AssetIO
 
 
 class TestAssetCentricMigrationIOAdapter:
@@ -19,11 +19,7 @@ class TestAssetCentricMigrationIOAdapter:
         csv_file = tmp_path / "files.csv"
         csv_file.write_text("id,space,externalId\n" + "\n".join(f"{i},mySpace,asset_{i}" for i in range(N)))
         selector = MigrationCSVFileSelector(datafile=csv_file, resource_type="asset")
-        adapter = AssetCentricMigrationIOAdapter(
-            client,
-            AssetIO(client),
-            InstanceIO(client),
-        )
+        adapter = AssetCentricMigrationIOAdapter(client, AssetIO(client))
         downloaded = list(adapter.stream_data(selector))
         assert len(downloaded) == 2
         assert sum(len(chunk) for chunk in downloaded) == N
